import { jsx as _jsx } from "react/jsx-runtime";
import { useDatasource } from "@nexcodepl/endpoint-client";
import { useStoreState } from "@nexcodepl/react-store";
import { useEffect } from "react";
import { RouteDataContext, useRouteDataContext } from "./routeDataContext.js";
import { EndpointStaticData } from "./Static.endpoint.js";
import { useStaticDataContext } from "./staticDataContext.js";
export function StaticDataProvider({ route, element, loader, error, routes, globalData }) {
    const staticDataContext = useStaticDataContext();
    const routeDataContext = useRouteDataContext({
        globalData,
        route,
        routes,
        routeData: staticDataContext.getData(route.id),
    });
    const dsRouteData = useDatasource(EndpointStaticData);
    const dsRouteDataState = useStoreState(dsRouteData.state);
    useEffect(() => {
        const routeData = staticDataContext.getData(route.id) ?? null;
        routeDataContext.routeDataStore.set(routeData);
        if (!routeData) {
            dsRouteData.load({ params: { dataId: route.id } });
        }
    }, [route.id]);
    useEffect(() => {
        if (dsRouteDataState.state === "completed") {
            routeDataContext.routeDataStore.set(dsRouteDataState.response);
            staticDataContext.setData(route.id, dsRouteDataState.response);
        }
    }, [dsRouteDataState.state]);
    if (dsRouteDataState.state === "error") {
        return error(dsRouteDataState);
    }
    if (dsRouteDataState.state === "pending" || routeDataContext.routeData === null) {
        return loader;
    }
    return _jsx(RouteDataContext.Provider, { value: routeDataContext, children: element });
}
